@@ -150,6 +150,19 @@ GList *                  gnome_vfs_mime_remove_component_from_list         (GLis
 GList *                  gnome_vfs_mime_id_list_from_component_list        (GList                   *components);
 GList *                  gnome_vfs_mime_id_list_from_application_list      (GList                   *applications);
 
+
+/* For launching mime actions & application */
+GnomeVFSResult           gnome_vfs_mime_action_launch                      (GnomeVFSMimeAction      *action,
+									    GList                   *uris);
+GnomeVFSResult           gnome_vfs_mime_action_launch_with_env             (GnomeVFSMimeAction      *action,
+									    GList                   *uris,
+									    char                   **envp);
+GnomeVFSResult           gnome_vfs_mime_application_launch                 (GnomeVFSMimeApplication *app,
+									    GList                   *uris);
+GnomeVFSResult           gnome_vfs_mime_application_launch_with_env	   (GnomeVFSMimeApplication *app,
+									    GList                   *uris,
+									    char                   **envp);
+
 G_END_DECLS
 
 #endif /* GNOME_VFS_MIME_HANDLERS_H */
