@@ -561,8 +561,16 @@ get_mime_type (GnomeVFSFileInfo *info,
 		 */
 		mime_type = "x-special/symlink";
 	} else {
-		mime_type = gnome_vfs_get_file_mime_type (full_name,
-			stat_buffer, (options & GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE) != 0);
+		if (options & GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE) {
+			mime_type = gnome_vfs_get_file_mime_type (full_name,
+								  stat_buffer, TRUE);
+		} else if (options & GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE) {
+			mime_type = gnome_vfs_get_file_mime_type (full_name,
+								  stat_buffer, FALSE);
+		} else {
+			mime_type = gnome_vfs_get_file_mime_type_fast (full_name,
+								       stat_buffer);
+		}
 	}
 
 	g_assert (mime_type);
@@ -2255,7 +2263,7 @@ monitor_setup (void)
 
 	if (fam_connection == NULL) {
 		fam_connection = g_malloc0(sizeof(FAMConnection));
-		if (FAMOpen2(fam_connection, "test-monitor") != 0) {
+		if (FAMOpen2(fam_connection, "gnome-vfs user") != 0) {
 #ifdef DEBUG_FAM
 			g_print ("FAMOpen failed, FAMErrno=%d\n", FAMErrno);
 #endif
